Introduced PasswordField.class.php to keep things simple.
[timetracker.git] / users.php
index 1233f11..da57040 100644 (file)
--- a/users.php
+++ b/users.php
@@ -44,9 +44,12 @@ if($user->canManageTeam()) {
   $inactive_users = ttTeamHelper::getInactiveUsers($user->team_id, true);
 }
 
-// Check each active user if they have an uncompleted time entry.
-foreach ($active_users as $key => $user) {
-  $active_users[$key]['has_uncompleted_entry'] = (bool) ttTimeHelper::getUncompleted($user['id']);
+// Check if the team is set to show indicators for uncompleted time entries.
+if (UNCOMPLETED_INDICATORS == $user->uncompleted_indicators) {
+  // Check each active user if they have an uncompleted time entry.
+  foreach ($active_users as $key => $user) {
+    $active_users[$key]['has_uncompleted_entry'] = (bool) ttTimeHelper::getUncompleted($user['id']);
+  }
 }
 
 $smarty->assign('active_users', $active_users);